@@ -3,13 +3,13 @@ from gcp_pilot.base import GoogleCloudPilotAPI, DiscoveryMixin, _CACHED_LOCATION
 
 class AppEngine(AppEngineBasedService, DiscoveryMixin, GoogleCloudPilotAPI):
     _scopes = [
-        'https://www.googleapis.com/auth/appengine.admin',
+        "https://www.googleapis.com/auth/appengine.admin",
     ]
 
     def __init__(self, **kwargs):
         super().__init__(
-            serviceName='appengine',
-            version='v1',
+            serviceName="appengine",
+            version="v1",
             cache_discovery=False,
             **kwargs,
         )
@@ -24,20 +24,18 @@ class AppEngine(AppEngineBasedService, DiscoveryMixin, GoogleCloudPilotAPI):
             appsId=app_id,
         )
 
-    def _get_default_location(self, default_zone: str = '1') -> str:
+    def _get_default_location(self, default_zone: str = "1") -> str:
         location = _CACHED_LOCATIONS.get(self.project_id, None)
 
         if not location:
             app = self.get_app()
-            location = app['locationId']
+            location = app["locationId"]
             try:
                 int(location[-1])
             except ValueError:
-                location = app['locationId'] + default_zone
+                location = app["locationId"] + default_zone
             _CACHED_LOCATIONS[self.project_id] = location
         return location
 
 
-__all__ = (
-    'AppEngine',
-)
+__all__ = ("AppEngine",)
